@@ -7,7 +7,7 @@ popsizedist.plot.landscape <- function(Rland)
   {
     if (is.landscape(Rland))
       {
-        plot.table(table(landscape.populations(Rland)),
+        plot(table(landscape.populations(Rland)),
                    main="Frequency distribution of population sizes",
                    xlab=c("Population"),
                    ylab=c("Number of individuals"),
@@ -20,7 +20,7 @@ stgsizedist.plot.landscape <- function(Rland)
   {
     if (is.landscape(Rland))
       {
-        plot.table(table(Rland$individuals[,1]+1),
+        plot(table(Rland$individuals[,1]+1),
                    main=c("Frequency distribution of demographic stage sizes"),
                    xlab=c("Demographic stage"),
                    ylab=c("Number of individuals"),
