@@ -5,10 +5,10 @@
 #samples the entire landscape, does not correct for sample bias
 #on the assumption that every individual is sampled
 
-Fst.landscape <- function(rland,verb=FALSE)
+landscape.Fst <- function(rland,verb=FALSE)
   {
-    aft <- allelefreq.landscape(rland,TRUE)
-    Fst <- matrix(0,length(ploidy(rland)),length(aft[1,,1]))
+    aft <- landscape.allelefreq(rland,TRUE)
+    Fst <- matrix(0,length(landscape.ploidy(rland)),length(aft[1,,1]))
     for (i in 1:length(Fst[,1]))
       {
         Fst[i,] <- ((colSums(sweep(aft[,,i],2,colMeans(aft[,,i]))^2)/(rland$intparam$habitats))/(colMeans(aft[,,i])*(1-colMeans(aft[,,i]))))
